@@ -6,11 +6,29 @@
 #include <QSettings>
 
 #define PLUGINPATH "/usr/lib/browser/plugins/libflashplayer.so"
+#ifdef Q_WS_MAEMO5
 #define PLUGINBACKPUPPATH_LEGACY "/home/user/MyDocs/libflashplayer.so.pr1.2"
 #define PLUGINBACKPUPPATH "/home/user/MyDocs/libflashplayer.so.pr12.tweakflashver"
 #define PLUGINSIZE 6723876
 #define OFFSET1 0x5B3D24
 #define OFFSET2 0x5CA71C
+#define PART1ORIG "9.0 r260"
+#define PART1LEN 8
+#define DIGITS 5
+#define PART2ORIG "LNX 9,0,260,0"
+#define PART2LEN 13
+#else
+#define PLUGINBACKPUPPATH_LEGACY "/home/user/MyDocs/libflashplayer.so.orig"
+#define PLUGINBACKPUPPATH "/home/user/MyDocs/libflashplayer.so.tweakflashver"
+#define PLUGINSIZE 5459364
+#define OFFSET1 0x48F5D8
+#define OFFSET2 0x499010
+#define PART1ORIG "9.0 r48"
+#define PART1LEN 7
+#define DIGITS 4
+#define PART2ORIG "LNX 9,0,48,0"
+#define PART2LEN 12
+#endif
 
 namespace Ui {
     class MainWindow;
